@@ -122,6 +122,51 @@ static PyMethodDef corba_functions[] = {
     { NULL, NULL, 0 }
 };
 
+static void
+add_tc_constants(PyObject *corbamod)
+{
+    PyModule_AddObject(corbamod, "TC_null",
+		       pycorba_typecode_new(TC_null));
+    PyModule_AddObject(corbamod, "TC_void",
+		       pycorba_typecode_new(TC_void));
+    PyModule_AddObject(corbamod, "TC_short",
+		       pycorba_typecode_new(TC_CORBA_short));
+    PyModule_AddObject(corbamod, "TC_long",
+		       pycorba_typecode_new(TC_CORBA_long));
+    PyModule_AddObject(corbamod, "TC_longlong",
+		       pycorba_typecode_new(TC_CORBA_long_long));
+    PyModule_AddObject(corbamod, "TC_ushort",
+		       pycorba_typecode_new(TC_CORBA_unsigned_short));
+    PyModule_AddObject(corbamod, "TC_ulong",
+		       pycorba_typecode_new(TC_CORBA_unsigned_long));
+    PyModule_AddObject(corbamod, "TC_ulonglong",
+		       pycorba_typecode_new(TC_CORBA_unsigned_long_long));
+    PyModule_AddObject(corbamod, "TC_float",
+		       pycorba_typecode_new(TC_CORBA_float));
+    PyModule_AddObject(corbamod, "TC_double",
+		       pycorba_typecode_new(TC_CORBA_double));
+    PyModule_AddObject(corbamod, "TC_longdouble",
+		       pycorba_typecode_new(TC_CORBA_long_double));
+    PyModule_AddObject(corbamod, "TC_boolean",
+		       pycorba_typecode_new(TC_CORBA_boolean));
+    PyModule_AddObject(corbamod, "TC_char",
+		       pycorba_typecode_new(TC_CORBA_char));
+    PyModule_AddObject(corbamod, "TC_wchar",
+		       pycorba_typecode_new(TC_CORBA_wchar));
+    PyModule_AddObject(corbamod, "TC_octet",
+		       pycorba_typecode_new(TC_CORBA_octet));
+    PyModule_AddObject(corbamod, "TC_any",
+		       pycorba_typecode_new(TC_CORBA_any));
+    PyModule_AddObject(corbamod, "TC_TypeCode",
+		       pycorba_typecode_new(TC_CORBA_TypeCode));
+    PyModule_AddObject(corbamod, "TC_Object",
+		       pycorba_typecode_new(TC_CORBA_Object));
+    PyModule_AddObject(corbamod, "TC_string",
+		       pycorba_typecode_new(TC_CORBA_string));
+    PyModule_AddObject(corbamod, "TC_wstring",
+		       pycorba_typecode_new(TC_CORBA_wstring));
+}
+
 static void
 register_corba_types(void)
 {
@@ -345,6 +390,7 @@ initORBit(void)
     pyorbit_register_exceptions(corbamod);
 
     register_corba_types();
+    add_tc_constants(corbamod);
 
     psmod = Py_InitModule("PortableServer", portableserver_functions);
     PyModule_AddObject(psmod, "POA",
