@@ -1,4 +1,22 @@
-/* -*- mode: C; c-basic-offset: 4 -*- */
+/* -*- mode: C; c-basic-offset: 4 -*-
+ * pyorbit - a Python language mapping for the ORBit2 CORBA ORB
+ * Copyright (C) 2002  James Henstridge <james@daa.com.au>
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+*/
+
 #ifdef HAVE_CONFIG_H
 #  include <config.h>
 #endif
@@ -46,6 +64,7 @@ pycorba_orb_string_to_object(PyCORBA_ORB *self, PyObject *args)
     CORBA_Object objref;
     CORBA_Environment ev;
     gchar *ior;
+    PyObject *py_objref;
 
     if (!PyArg_ParseTuple(args, "s:CORBA.ORB.string_to_object", &ior))
 	return NULL;
@@ -54,7 +73,9 @@ pycorba_orb_string_to_object(PyCORBA_ORB *self, PyObject *args)
     objref = CORBA_ORB_string_to_object(self->orb, ior, &ev);
     if (pyorbit_check_ex(&ev))
 	return NULL;
-    return pycorba_object_new(objref);
+    py_objref = pycorba_object_new(objref);
+    CORBA_Object_release(objref, NULL);
+    return py_objref;
 }
 
 static PyObject *
@@ -85,6 +106,7 @@ pycorba_orb_resolve_initial_references(PyCORBA_ORB *self, PyObject *args)
     CORBA_Object objref;
     CORBA_Environment ev;
     gchar *identifier;
+    PyObject *py_objref;
 
     if (!PyArg_ParseTuple(args, "s:CORBA.ORB.resolve_initial_references",
 			  &identifier))
@@ -98,7 +120,9 @@ pycorba_orb_resolve_initial_references(PyCORBA_ORB *self, PyObject *args)
     if (!strcmp(identifier, "RootPOA")) {
 	return pyorbit_poa_new((PortableServer_POA)objref);
     }
-    return pycorba_object_new(objref);
+    py_objref = pycorba_object_new(objref);
+    CORBA_Object_release(objref, NULL);
+    return py_objref;
 }
 
 static PyObject *
